const express = require('express');
const router = express.Router();
const models = require('../schemas/models');
const routes = require('./index');
const upload = require('../multer-config')


const Announcement = models.Announcement;
const isAuthenticated = routes.isAuthenticated;

// Route pour récupérer toutes les annonces
router.get('/', async (req, res) => {
    try {
        const announcements = await Announcement.find();
        let isAuthenticated = false;
        if (req.isAuthenticated()) {
            isAuthenticated = true;
        }
        res.render('announcements', { announcements: announcements, isAuthenticated: isAuthenticated });
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
});

// Route pour afficher la page d'ajout d'annonce
router.get('/add-announcement', isAuthenticated, (req, res) => {
    res.render('add_announcement');
});

// details de l'annonce
router.get('/:id', async (req, res) => {
    try {
        const announcementId = req.params.id;
        const announcementDetails = await Announcement.findById(announcementId);
        res.render('announcement_details', { announcement: announcementDetails });
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
});

router.post('/add-announcement', isAuthenticated, upload.array('photos', ), async (req, res) => {
    const { title, propertyType, publicationStatus, propertyStatus, description, price, availabilityDate} = req.body;
    const photos = req.files.map(file => file.filename);

    const user = req.user;

    const newAnnouncement = new Announcement({
        title,
        propertyType,
        publicationStatus,
        propertyStatus,
        description,
        price,
        availabilityDate,
        photos,
        userName: user.username
    });

    try {
        await newAnnouncement.save();
        const announcements = await Announcement.find();
        res.redirect('/announcements');
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
});

module.exports = router;
